@@ -11,7 +11,7 @@ from perm import *
 from utils import *
 from pythonic import *
 from etc import *
-
+from user import *
 
 try:
     import pkg_resources  # in package
@@ -57,7 +57,7 @@ def rm_server_nginx():
     pass
 
 
-def server_redis(card='eth0', size=None, newer='remi'):
+def server_redis(card=None, size=None, newer='remi'):
     """
     Install redis server
     @todo support set unixsocket
@@ -80,7 +80,12 @@ def server_redis(card='eth0', size=None, newer='remi'):
     run('chown redis.redis /storage/redis')
     run('chkconfig --level 35 redis on')
 
-    ip = cmd_ip(card)
+
+    if card:
+        ip = cmd_ip(card)
+    else:
+        ip = '0.0.0.0'
+
     run('sed -i -e "s/\(bind\s*\)[0-9\.]*/\\1%s/g" /etc/redis.conf' % ip)
 
     # if size:
@@ -483,9 +488,11 @@ def server_monit(version='5.5-1'):
     # run('for i in `rpm -ql monit`;do rm -rf $i; done;')
     # run('rpm -e `rpm -qa | grep -i monit`')
 
-    with settings(warn_only=True):
-        run('rpm -ivh  https://github.com/nextoa/monit-bin/raw/master/monit-{}.el6.rf.x86_64.rpm'.format(version))
-        run('rpm -Uvh  https://github.com/nextoa/monit-bin/raw/master/monit-{}.el6.rf.x86_64.rpm'.format(version))
+    # with settings(warn_only=True):
+    # run('rpm -ivh  https://github.com/nextoa/monit-bin/raw/master/monit-{}.el6.rf.x86_64.rpm'.format(version))
+    # run('rpm -Uvh  https://github.com/nextoa/monit-bin/raw/master/monit-{}.el6.rf.x86_64.rpm'.format(version))
+
+    yum_install('monit', 'remi')
     run('chkconfig --level 35 monit on')
     pass
 
@@ -529,6 +536,9 @@ def server_nodejs(user='webuser'):
 def server_statsd(root, repo='https://github.com/nextoa/statsd.git', user='webuser'):
     # run('pip install graphite')
 
+    utils_baselib()
+    classic_git()
+
     server_nodejs(user)
     io_slowlog('statsd', user)
     cmd_git(root, repo, branch='master', user=user)
@@ -583,6 +593,8 @@ def server_graphite(user='webuser', port='10002', python='2.6'):
     """
     yum_install('bitmap bitmap-fonts-compat cairo-devel python-whisper python-carbon graphite-web python-memcached memcached')
     run('/usr/bin/python /usr/lib/python{}/site-packages/graphite/manage.py syncdb'.format(python))
+    run('chown {0}.{0} /var/lib/graphite-web/graphite.db'.format(user))
+    run('chown -Rf {0}.{0} /var/log/graphite-web'.format(user))
     run('chkconfig --level 35 carbon-cache on')
     run('chkconfig --level 35 memcached on')
 
@@ -593,9 +605,9 @@ def server_graphite(user='webuser', port='10002', python='2.6'):
     #
     # with cd('/tmp/{}-{}'.format(name,version)):
     # run('/usr/local/pypy/bin/pypy setup.py install')
-    #     pass
+    # pass
 
-    ## pip('cairocffi')
+    # # pip('cairocffi')
     # pip('graphite-web')
     # pip('carbon')
     # pip('whisper')
@@ -628,8 +640,6 @@ def server_statsdsuite(user='webuser', monit=None):
     server_statsd('/webdata/statsd', user=user)
     server_grafana('/webdata/grafana', user=user)
 
-    run('chown {0}.{0} /var/lib/graphite-web/graphite.db'.format(user))
-
     pass
 
 
@@ -639,10 +649,10 @@ def server_statsdsuite(user='webuser', monit=None):
 #
 # yum_install('sendmail', newer="remi")
 #
-#     run('chkconfig --level 35 sendmail on')
+# run('chkconfig --level 35 sendmail on')
 #
-#     with settings(warn_only=True):
-#         run("sed -i -e \"s/^DAEMON_OPTIONS.*dnl/DAEMON_OPTIONS(\\\`Port=smtp,Name=MTA\')dnl/g\" /etc/mail/sendmail.mc")
+# with settings(warn_only=True):
+# run("sed -i -e \"s/^DAEMON_OPTIONS.*dnl/DAEMON_OPTIONS(\\\`Port=smtp,Name=MTA\')dnl/g\" /etc/mail/sendmail.mc")
 #
 #
 # # yum install postfix dovecot
@@ -669,10 +679,9 @@ def server_smtp(host, domain, networks):
 
     buf = template.replace('{$myhostname}', host) \
         .replace('{$mydomain}', domain) \
-        .replace('{$mynetworks}', networks) \
- \
- \
-        # only support python2.x
+        .replace('{$mynetworks}', networks)
+
+    # only support python2.x
     with tempfile.NamedTemporaryFile('w', delete=False) as fh:
         print>> fh, buf
 
@@ -694,10 +703,13 @@ def restart_web(config=None):
     run('service tengine restart')
 
 
-def restart_monit(config=None):
+def reboot_monit(name, config=None):
     if config:
         config_monit(config)
-    run('service monit restart')
+        run('service monit restart')
+
+    run('monit restart {}'.format(name))
+    # run('service monit restart')
 
 
 
